==> openshift-model-operatorhub-6.5.1-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/NamedInstallStrategyFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface NamedInstallStrategyFluent<A extends NamedInstallStrategyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StrategyDetailsDeployment getSpec();
  public StrategyDetailsDeployment buildSpec();
  public A withSpec(StrategyDetailsDeployment spec);
  public Boolean hasSpec();
  public NamedInstallStrategyFluent.SpecNested<A> withNewSpec();
  public NamedInstallStrategyFluent.SpecNested<A> withNewSpecLike(StrategyDetailsDeployment item);
  public NamedInstallStrategyFluent.SpecNested<A> editSpec();
  public NamedInstallStrategyFluent.SpecNested<A> editOrNewSpec();
  public NamedInstallStrategyFluent.SpecNested<A> editOrNewSpecLike(StrategyDetailsDeployment item);
  public String getStrategy();
  public A withStrategy(String strategy);
  public Boolean hasStrategy();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SpecNested<N> extends Nested<N>,StrategyDetailsDeploymentFluent<NamedInstallStrategyFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}

==> openshift-model-operatorhub-6.7.2-sources.jar: io/fabric8/openshift/api/model/operatorhub/v1alpha1/NamedInstallStrategyFluent.java <==
package io.fabric8.openshift.api.model.operatorhub.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamedInstallStrategyFluent<A extends NamedInstallStrategyFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public StrategyDetailsDeployment getSpec();
  public StrategyDetailsDeployment buildSpec();
  public A withSpec(StrategyDetailsDeployment spec);
  public Boolean hasSpec();
  public NamedInstallStrategyFluent.SpecNested<A> withNewSpec();
  public NamedInstallStrategyFluent.SpecNested<A> withNewSpecLike(StrategyDetailsDeployment item);
  public NamedInstallStrategyFluent.SpecNested<A> editSpec();
  public NamedInstallStrategyFluent.SpecNested<A> editOrNewSpec();
  public NamedInstallStrategyFluent.SpecNested<A> editOrNewSpecLike(StrategyDetailsDeployment item);
  public String getStrategy();
  public A withStrategy(String strategy);
  public Boolean hasStrategy();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface SpecNested<N> extends Nested<N>,StrategyDetailsDeploymentFluent<NamedInstallStrategyFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  
}
